##  Viewing and Recovering the Archived Fact Sheets
To recover an archived fact sheet within the retention period:
  1. Use the filter function in the Inventory and search and apply the filter - Archived.
![Search and Apply the filter - Archived](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274966f27a441014901ffcc50c6c54e0_LowRes.png)
Search and Apply the filter - Archived
  2. From the filtered list, open the archived fact sheet you want to recover.
  3. From the menu at the top right corner, select Recover.
